#ifndef POKEPLATINUM_UNK_0202ACE0_H
#define POKEPLATINUM_UNK_0202ACE0_H

#include "strbuf.h"
#include "struct_decls/struct_0202B370_decl.h"
#include "struct_decls/struct_021C0794_decl.h"

#include <dwc.h>

int sub_0202ACE0(void);
void sub_0202ACE8(UnkStruct_0202B370 * param0);
DWCUserData * sub_0202AD28(UnkStruct_0202B370 * param0);
u32 sub_0202AD2C(UnkStruct_0202B370 * param0, int param1, int param2);
void sub_0202AE2C(UnkStruct_0202B370 * param0, int param1, int param2, u32 param3);
DWCFriendData * sub_0202AED8(UnkStruct_0202B370 * param0, int param1);
u16 * sub_0202AEF0(UnkStruct_0202B370 * param0, int param1);
void sub_0202AF0C(UnkStruct_0202B370 * param0, int param1, Strbuf *param2);
u16 * sub_0202AF34(UnkStruct_0202B370 * param0, int param1);
void sub_0202AF50(UnkStruct_0202B370 * param0, int param1, Strbuf *param2);
BOOL sub_0202AF78(UnkStruct_0202B370 * param0, int param1);
int sub_0202AF94(UnkStruct_0202B370 * param0);
int sub_0202AFB4(UnkStruct_0202B370 * param0);
void sub_0202AFD4(UnkStruct_0202B370 * param0, int param1);
void sub_0202B0F8(UnkStruct_0202B370 * param0);
void sub_0202B13C(UnkStruct_0202B370 * param0, int param1);
void sub_0202B174(UnkStruct_0202B370 * param0, int param1, int param2, int param3, int param4);
void sub_0202B1D0(UnkStruct_0202B370 * param0, int param1, int param2);
void sub_0202B1F8(UnkStruct_0202B370 * param0, int param1, int param2);
void sub_0202B220(UnkStruct_0202B370 * param0, int param1, int param2);
void sub_0202B248(UnkStruct_0202B370 * param0, int param1, int param2);
void sub_0202B270(UnkStruct_0202B370 * param0, int param1, int param2);
UnkStruct_0202B370 * sub_0202B370(UnkStruct_021C0794 * param0);

#endif // POKEPLATINUM_UNK_0202ACE0_H
